@@ -1,5 +1,5 @@
 """Asynchronous Python wrapper library over Bond Local API."""
 
-from .bond import Bond  # noqa: F401
+from .bond import Bond, BPUPSubscriptions, start_bpup  # noqa: F401
 from .action import Action, Direction  # noqa: F401
 from .device_type import DeviceType  # noqa: F401
