@@ -7,6 +7,7 @@ from asyncio import transports
 from typing import Any, Callable, List, Optional
 
 from aiohttp import ClientSession, ClientTimeout
+from aiohttp.client_exceptions import ServerDisconnectedError
 
 from .action import Action
 
@@ -64,15 +65,23 @@ class Bond:
 
     async def action(self, device_id: str, action: Action) -> None:
         """Execute given action for a given device."""
-        path = f"/v2/devices/{device_id}/actions/{action.name}"
+        if action.name == Action.SET_STATE_BELIEF:
+            path = f"/v2/devices/{device_id}/state"
+            async def patch(session: ClientSession) -> None:
+                async with session.patch(
+                    f"http://{self._host}{path}", **self._api_kwargs, json=action.argument
+                ) as response:
+                    response.raise_for_status()
+            await self.__call(patch)
+        else:
+            path = f"/v2/devices/{device_id}/actions/{action.name}"
+            async def put(session: ClientSession) -> None:
+                async with session.put(
+                    f"http://{self._host}{path}", **self._api_kwargs, json=action.argument
+                ) as response:
+                    response.raise_for_status()
+            await self.__call(put)
 
-        async def put(session: ClientSession) -> None:
-            async with session.put(
-                f"http://{self._host}{path}", **self._api_kwargs, json=action.argument
-            ) as response:
-                response.raise_for_status()
-
-        await self.__call(put)
 
     async def __get(self, path) -> dict:
         async def get(session: ClientSession) -> dict:
@@ -89,7 +98,12 @@ class Bond:
             async with ClientSession() as request_session:
                 return await handler(request_session)
         else:
-            return await handler(self._session)
+            try:
+                return await handler(self._session)
+            except ServerDisconnectedError:
+                # bond has a short connection close time
+                # so we need to retry if we idled for a bit
+                return await handler(self._session)
 
 
 class BPUPSubscriptions:
